@@ -279,7 +279,7 @@ class HistoryManager:
             path = rowref.get_path()
             if path is None:
                 continue
-            jid = liststore[path][0] # jid
+            jid = liststore[path][0].decode('utf-8') # jid
             self._fill_logs_listview(jid)
 
     def _get_jid_id(self, jid):
@@ -471,10 +471,11 @@ class HistoryManager:
         dlg.destroy()
 
     def on_delete_menuitem_activate(self, widget, listview):
+        widget_name = gtk.Buildable.get_name(listview)
         liststore, list_of_paths = listview.get_selection().get_selected_rows()
-        if listview.name == 'jids_listview':
+        if widget_name == 'jids_listview':
             self._delete_jid_logs(liststore, list_of_paths)
-        elif listview.name in ('logs_listview', 'search_results_listview'):
+        elif widget_name in ('logs_listview', 'search_results_listview'):
             self._delete_logs(liststore, list_of_paths)
         else: # Huh ? We don't know this widget
             return
@@ -625,7 +626,7 @@ class HistoryManager:
     def on_search_results_listview_row_activated(self, widget, path, column):
         # get log_line_id, jid_id from row we double clicked
         log_line_id = self.search_results_liststore[path][0]
-        jid = self.search_results_liststore[path][1]
+        jid = self.search_results_liststore[path][1].decode('utf-8')
         # make it string as in gtk liststores I have them all as strings
         # as this is what db returns so I don't have to fight with types
         jid_id = self._get_jid_id(jid)
